Learn R Programming

rcrisp (version 0.3.1)

build_river_network: Build a spatial network from river centerlines

Description

If a bounding box is provided, only the river segments that intersect it are considered. If the river intersects the bounding box multiple times, only the longest intersecting segment will be considered.

Usage

build_river_network(river, bbox = NULL)

Value

An sfnetworks::sfnetwork object

Arguments

river

A (MULTI)LINESTRING simple feature geometry representing the river centerline

bbox

Bounding box of the area of interest