check_cache: Check cache

View source: R/cache.R

check_cacheR Documentation

Check cache

Description

A warning is raised if the cache size is > 100 MB or if it includes files older than 30 days.

Usage

check_cache()

Value

NULL

Examples


check_cache()


rcrisp documentation built on Nov. 24, 2025, 5:07 p.m.