clear_cache: Remove cache files

View source: R/cache.R

clear_cacheR Documentation

Remove cache files

Description

Remove files from cache directory either before a given date or entirely.

Usage

clear_cache(before_date = NULL)

Arguments

before_date

Date before which cache files should be removed provided as object of class Date or as a case dependent character vector accepted by as.Date()

Value

List of file paths of removed files

Examples


# Clear all cache
clear_cache()

# Clear cache before given date
before_date <- as.Date("1-1-1999", "%m-%d-%Y")
clear_cache(before_date = before_date)


rcrisp documentation built on Nov. 24, 2025, 5:07 p.m.