| delineate_segments | R Documentation |
Segments are defined as corridor subregions separated by river-crossing transversal lines that form continuous strokes in the network.
delineate_segments(corridor, network, river, angle_threshold = 100)
corridor |
The river corridor as a simple feature geometry of class
|
network |
The spatial network of class |
river |
The river centerline as a simple feature geometry of class
|
angle_threshold |
Only consider angles above this threshold (in degrees)
to form continuous strokes in the network. The value can range between
0 and 180, with the default set to 100. See |
Segment polygons as a simple feature geometry of class
sf::sfc_POLYGON
bucharest_osm <- get_osm_example_data()
corridor <- bucharest_dambovita$corridor
network <- rbind(bucharest_osm$streets, bucharest_osm$railways) |>
as_network()
river <- bucharest_osm$river_centerline
delineate_segments(corridor, network, river)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.