Skip to contents

An S3 class representing the result of a delineation as returned by delineate().

Value

An object of class delineation containing zero or more of the spatial layers $valley, $corridor, $segments, and $riverspace (each an sf::sfc_POLYGON or sf::sfc_MULTIPOLYGON object), plus the base OSM and optionally DEM layers and an $aoi list with the delineation parameters produced by define_aoi(). See delineate() for details.

Examples

if (FALSE) { # interactive()
bd <- delineate_city_river("Bucharest", "Dâmbovița")
class(bd)
}