get_corridor_edges: Split corridor along the river to find edges on the two banks

View source: R/segments.R

get_corridor_edgesR Documentation

Split corridor along the river to find edges on the two banks

Description

Split corridor along the river to find edges on the two banks

Usage

get_corridor_edges(corridor, river)

Arguments

corridor

The river corridor as a simple feature geometry

river

The river centerline as a simple feature geometry

Value

Corridor edges as an object of class sf::sfc_LINESTRING


rcrisp documentation built on Nov. 24, 2025, 5:07 p.m.