| get_dem | R Documentation |
Access digital elevation model (DEM) for a given region
get_dem(
bb,
dem_source = "STAC",
stac_endpoint = NULL,
stac_collection = NULL,
crs = NULL,
force_download = FALSE
)
bb |
A bounding box, provided either as a matrix (rows for "x", "y",
columns for "min", "max") or as a vector ("xmin", "ymin", "xmax", "ymax"),
in lat/lon coordinates (WGS84 coordinate reference system) of class |
dem_source |
Source of the DEM:
|
stac_endpoint |
URL of the STAC API endpoint (only used if |
stac_collection |
Identifier of the STAC collection to be queried (only
used if |
crs |
Coordinate reference system (CRS) which to transform the DEM to |
force_download |
Download data even if cached data is available |
DEM as a terra SpatRaster object
# Get DEM with default values
bb <- get_osm_bb("Bucharest")
crs <- 31600 # National projected CRS
# Get DEM with default values
get_dem(bb)
# Get DEM from custom STAC endpoint
get_dem(bb,
stac_endpoint = "some endpoint",
stac_collection = "some collection")
# Specify CRS
get_dem(bb, crs = crs)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.