| get_dem_example_data | R Documentation |
This function retrieves example Digital Elevation Model (DEM) data from the Zenodo data repository, and it can be used in examples and tests. The code used to generate the example dataset is available at https://github.com/CityRiverSpaces/CRiSpExampleData. Note that the example dataset is cached locally, so that subsequent calls to the function can load the example data from disk without having to re-download the data.
get_dem_example_data(force_download = FALSE)
force_download |
Download data even if cached data is available |
An object of class terra::SpatRaster containing the DEM data.
get_dem_example_data(force_download = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.