get_example_cache_filepath: Get file path where to cache example data files

View source: R/cache.R

get_example_cache_filepathR Documentation

Get file path where to cache example data files

Description

The function returns the file path where to store example data files that are retrieved from a data repository (see get_osm_example_data() and get_dem_example_data()). The directory used is the one returned by cache_directory().

Usage

get_example_cache_filepath(filename)

Arguments

filename

The name of the file to be retrieved from the data repository

Value

A character string representing the file path


rcrisp documentation built on Nov. 24, 2025, 5:07 p.m.