| get_example_data_file | R Documentation |
Store the file in the cache directory, for subsequent reuse.
get_example_data_file(filename, force_download = FALSE)
force_download |
Download data even if cached data is available |
A character string representing the file path
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.