get_intersecting_edges: Identify network edges that are intersecting a geometry

View source: R/network.R

get_intersecting_edgesR Documentation

Identify network edges that are intersecting a geometry

Description

Identify network edges that are intersecting a geometry

Usage

get_intersecting_edges(network, geometry, index = FALSE)

Arguments

network

A spatial network object of class sfnetworks::sfnetwork

geometry

An object of class sf::sfc

index

Whether to return the indices of the matchin edges or the geometries

Value

Indices or geometries of the edges intersecting the given geometry of class sf::sfc_LINESTRING


rcrisp documentation built on Nov. 24, 2025, 5:07 p.m.