get_osm_railways: Get OpenStreetMap railways

View source: R/osmdata.R

get_osm_railwaysR Documentation

Get OpenStreetMap railways

Description

Get OpenStreetMap railways

Usage

get_osm_railways(
  aoi,
  crs = NULL,
  railway_values = "rail",
  force_download = FALSE
)

Arguments

aoi

Area of interest as sf object or bbox

crs

A numeric vector of length one with the EPSG code of the CRS

railway_values

A case-insensitive character vector with the railway values to retrieve.

force_download

Download data even if cached data is available

Value

An object of class sf::sfc_LINESTRING

Examples


bb <- get_osm_bb("Bucharest")
crs <- get_utm_zone(bb)
get_osm_railways(aoi = bb, crs = crs)


rcrisp documentation built on Nov. 24, 2025, 5:07 p.m.