| get_river_aoi | R Documentation |
Get an area of interest (AoI) around a river, cropping to the bounding box of a city
get_river_aoi(river, city_bbox, buffer_distance)
river |
A |
city_bbox |
Bounding box of class |
buffer_distance |
A positive number representing the buffer size around the river in meters. The upper limit is unrestricted. |
An sf::sfc_POLYGON object in lat/lon coordinates
bb <- get_osm_bb("Bucharest")
river_centerline <- get_osm_river_centerline(bb, "Dâmbovița")
river_surface <- get_osm_river_surface(bb, "Dâmbovița")
river <- list(centerline = river_centerline, surface = river_surface)
get_river_aoi(river = river, city_bbox = bb, buffer_distance = 100)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.