get_river_banks: Draw the regions corresponding to the two river banks

View source: R/corridor.R

get_river_banksR Documentation

Draw the regions corresponding to the two river banks

Description

These are constructed as single-sided buffers around the river geometry (see river_buffer() for the implementation and refinement steps).

Usage

get_river_banks(river, width)

Arguments

river

River spatial features provided as a sfnetworks::sfnetwork or sf::sf/sf::sfc object.

width

Width of the regions

Value

A sf::sfc_POLYGON object with two polygon features


rcrisp documentation built on Nov. 24, 2025, 5:07 p.m.