Learn R Programming

rcrisp (version 0.3.1)

get_valley_polygon: Create vector/polygon representation of valley without holes from raster mask

Description

Create vector/polygon representation of valley without holes from raster mask

Usage

get_valley_polygon(valley_mask)

Value

(multi)polygon representation of valley area as a simple feature geometry without holes

Arguments

valley_mask

raster mask of valley pixels