initial_edges: Identify the initial edges of the river corridor

View source: R/corridor.R

initial_edgesR Documentation

Identify the initial edges of the river corridor

Description

These are defined by splitting the initial corridor boundary into the sub-regions that the river forms in the area of interest

Usage

initial_edges(corridor_initial, regions)

Arguments

corridor_initial

A simple feature geometry representing the area of the initial corridor

regions

A simple feature geometry representing the sub-regions formed by cutting the area of interest along the river

Value

An sf::sfc_LINESTRING or sf::sfc_MULTILINESTRING object representing the initial corridor edges


rcrisp documentation built on Nov. 24, 2025, 5:07 p.m.