| load_dem | R Documentation |
Load DEM data from a list of tiles, crop and merge using a given bounding box to create a raster DEM for the specified region. Results are cached, so that new queries with the same input parameters will be loaded from disk.
load_dem(bb, tile_urls, force_download = FALSE)
bb |
A bounding box, provided either as a matrix (rows for "x", "y",
columns for "min", "max") or as a vector ("xmin", "ymin", "xmax", "ymax")
of class |
tile_urls |
A list of tiles where to read the DEM data from |
force_download |
Download data even if cached data is available |
A DEM of class terra::SpatRaster, retrieved and retiled to the
given bounding box
bb <- get_osm_bb("Bucharest")
tile_urls <- get_stac_asset_urls(bb)
load_dem(bb = bb, tile_urls = tile_urls, force_download = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.