nearest_node: Find the node in a network that is closest to a target...

View source: R/network.R

nearest_nodeR Documentation

Find the node in a network that is closest to a target geometry.

Description

Find the node in a network that is closest to a target geometry.

Usage

nearest_node(network, target)

Arguments

network

A network object of class sfnetworks::sfnetwork

target

An object of class sf::sf or sf::sfc

Value

A node in the network as an object of class sf::sfc_POINT


rcrisp documentation built on Nov. 24, 2025, 5:07 p.m.