Learn R Programming

rcrisp (version 0.3.1)

set_units_like: Set the units of x as the units of y

Description

Set the units of x as the units of y

Usage

set_units_like(x, y)

Value

Object x with units of y

Arguments

x

x (can be unitless)

y

y (can be unitless)