If a bounding box is provided, only the river segments that intersect it are considered. If the river intersects the bounding box multiple times, only the longest intersecting segment will be considered.
build_river_network(river, bbox = NULL)An sfnetworks::sfnetwork object
A (MULTI)LINESTRING simple feature geometry representing the river centerline
Bounding box of the area of interest