| clear_cache | R Documentation |
Remove files from cache directory either before a given date or entirely.
clear_cache(before_date = NULL)
before_date |
Date before which cache files should be removed provided
as object of class |
List of file paths of removed files
# Clear all cache
clear_cache()
# Clear cache before given date
before_date <- as.Date("1-1-1999", "%m-%d-%Y")
clear_cache(before_date = before_date)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.