| delineate | R Documentation |
Delineate a corridor around a river
delineate(
city_name,
river_name,
crs = NULL,
network_buffer = NULL,
buildings_buffer = NULL,
corridor_init = "valley",
dem = NULL,
dem_buffer = 2500,
max_iterations = 10,
capping_method = "shortest-path",
angle_threshold = 100,
corridor = TRUE,
segments = FALSE,
riverspace = FALSE,
force_download = FALSE,
...
)
city_name |
A character vector of length one |
river_name |
A character vector of length one |
crs |
The projected Coordinate Reference System (CRS) to use. If not provided, the suitable Universal Transverse Mercator (UTM) CRS is selected |
network_buffer |
Add a buffer (an integer in meters) around river to retrieve additional data (streets, railways, etc.). Default is 3000 m. |
buildings_buffer |
Add a buffer (an integer in meters) around the river to retrieve additional data (buildings). Default is 100 m. |
corridor_init |
How to estimate the initial guess of the river corridor. It can take the following values:
|
dem |
Digital elevation model (DEM) of the region (only used if
|
dem_buffer |
Size of the buffer region (in meters) around the
river to retrieve the DEM (only used if |
max_iterations |
Maximum number of iterations employed to refine the
corridor edges (see |
capping_method |
The method employed to connect the corridor edge end
points (i.e., to "cap" the corridor), as character vector of length one.
See |
angle_threshold |
Only network edges forming angles above this threshold
(in degrees) are considered when forming segment edges. See
|
corridor |
Whether to carry out the corridor delineation |
segments |
Whether to carry out the corridor segmentation |
riverspace |
Whether to carry out the riverspace delineation |
force_download |
Download data even if cached data is available |
... |
Additional (optional) input arguments for retrieving the DEM
dataset (see |
A list with the corridor, segments, and riverspace geometries as
sf::sfc_POLYGON objects.
# Set parameters
city <- "Bucharest"
river <- "Dâmbovița"
# Delineate with defaults
delineate(city, river)
# Use custom CRS
delineate(city, river, crs = "EPSG:31600") # National projected CRS
# Use custom network buffer
delineate(city, river, network_buffer = 3500)
# Use custom buildings buffer
delineate(city, river, buildings_buffer = 150, riverspace = TRUE)
# Provide DEM as input
bucharest_dem <- get_dem_example_data()
delineate(city, river, dem = bucharest_dem)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.