powered by
Delineate the space surrounding a river
delineate_riverspace( river, occluders = NULL, density = 1/50, ray_num = 40, ray_length = 100 )
Riverspace as object of class sf::sfc_POLYGON
sf::sfc_POLYGON
List with river surface and centerline
Geometry of occluders
Density of viewpoints
Number of rays as numeric vector of length one
Length of rays in meters as numeric vector of length one
if (FALSE) { # interactive() bucharest_osm <- get_osm_example_data() delineate_riverspace(bucharest_osm$river_surface, bucharest_osm$buildings) }
Run the code above in your browser using DataLab