delineate_valley: Extract the river valley from the DEM
Description
The slope of the digital elevation model (DEM) is used as friction (cost)
surface to compute the cost distance from any grid cell of the raster to
the river. A characteristic value (default: the mean) of the cost distance
distribution in a region surrounding the river (default: a buffer region of
2 km) is then calculated, and used to threshold the cost-distance surface.
The resulting area is then "polygonized" to obtain the valley boundary as a
simple feature geometry.
Usage
delineate_valley(dem, river)
Value
River valley as a simple feature geometry of class sfc_MULTIPOLYGON
Arguments
dem
SpatRaster object with the digital elevation model of the region
river
An object of class sf::sf or sf::sfc
representing the river