Learn R Programming

rcrisp (version 0.3.1)

get_corridor_edges: Split corridor along the river to find edges on the two banks

Description

Split corridor along the river to find edges on the two banks

Usage

get_corridor_edges(corridor, river)

Value

Corridor edges as an object of class sf::sfc_LINESTRING

Arguments

corridor

The river corridor as a simple feature geometry

river

The river centerline as a simple feature geometry