get_corridor_edges: Split corridor along the river to find edges on the two banks
Description
Split corridor along the river to find edges on the two banks
Usage
get_corridor_edges(corridor, river)
Arguments
- corridor
The river corridor as a simple feature geometry
- river
The river centerline as a simple feature geometry