| get_example_cache_filepath | R Documentation |
The function returns the file path where to store example data files that
are retrieved from a data repository (see get_osm_example_data() and
get_dem_example_data()). The directory used is the one returned by
cache_directory().
get_example_cache_filepath(filename)
filename |
The name of the file to be retrieved from the data repository |
A character string representing the file path
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.