powered by
Get OpenStreetMap railways
get_osm_railways( aoi, crs = NULL, railway_values = "rail", force_download = FALSE )
An object of class sf::sfc_LINESTRING
sf::sfc_LINESTRING
Area of interest as sf object or bbox
A numeric vector of length one with the EPSG code of the CRS
A case-insensitive character vector with the railway values to retrieve.
Download data even if cached data is available
if (FALSE) { # interactive() bb <- get_osm_bb("Bucharest") crs <- get_utm_zone(bb) get_osm_railways(aoi = bb, crs = crs) }
Run the code above in your browser using DataLab