| get_osm_river_centerline | R Documentation |
Get the river centreline from OpenStreetMap
get_osm_river_centerline(bb, river_name, crs = NULL, force_download = FALSE)
bb |
Bounding box of class |
river_name |
The name of the river as character vector of length 1, case-sensitive. |
crs |
Coordinate reference system as EPSG code |
force_download |
Download data even if cached data is available |
The river centreline as object of class sf::sfc_LINESTRING or
sf::sfc_MULTILINESTRING.
bb <- get_osm_bb("Bucharest")
crs <- get_utm_zone(bb)
get_osm_river_centerline(bb = bb, river_name = "Dâmbovița", crs = crs,
force_download = FALSE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.