| nearest_node | R Documentation |
Find the node in a network that is closest to a target geometry.
nearest_node(network, target)
network |
A network object of class |
target |
An object of class |
A node in the network as an object of class sf::sfc_POINT
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.