Learn R Programming

rcrisp (version 0.3.1)

rcrisp-package: rcrisp: Automate the Delineation of Urban River Spaces

Description

Provides tools to automate the morphological delineation of riverside urban areas based on a method introduced in Forgaci (2018) tools:::Rd_expr_doi("10.7480/abe.2018.31"). Delineation entails the identification of corridor boundaries, segmentation of the corridor, and delineation of the river space using two-dimensional spatial information from street network data and digital elevation data in a projected CRS. The resulting delineation can be used to characterise spatial phenomena that can be related to the river as a central element.

Arguments

Author

Maintainer: Claudiu Forgaci c.forgaci@tudelft.nl (ORCID) [copyright holder]

Authors:

Other contributors:

See Also

Useful links: