Provides tools to automate the morphological delineation of riverside urban areas based on a method introduced in Forgaci (2018) tools:::Rd_expr_doi("10.7480/abe.2018.31"). Delineation entails the identification of corridor boundaries, segmentation of the corridor, and delineation of the river space using two-dimensional spatial information from street network data and digital elevation data in a projected CRS. The resulting delineation can be used to characterise spatial phenomena that can be related to the river as a central element.
Maintainer: Claudiu Forgaci c.forgaci@tudelft.nl (ORCID) [copyright holder]
Authors:
Francesco Nattino f.nattino@esciencecenter.nl (ORCID)
Other contributors:
Fakhereh Alidoost f.alidoost@esciencecenter.nl (ORCID) [contributor]
Meiert Willem Grootes m.grootes@esciencecenter.nl (ORCID) [contributor]
Netherlands eScience Center info@esciencecenter.nl [funder]
Useful links:
tools:::Rd_expr_doi("10.5281/zenodo.15793526")
Report bugs at https://github.com/CityRiverSpaces/rcrisp/issues